#include <iostream>
#include <fstream>
#include <string>
#include <vector>
#include <map>

// 定义一个结构体来存储配置项
struct ConfigItem {
    std::string section;
    std::string key;
    std::string value;
};

// 函数：生成配置文件内容
void generateConfig(std::ofstream& file, const std::vector<ConfigItem>& items) {
    for (const auto& item : items) {
        if (!item.section.empty()) {
            file << "[" << item.section << "]\n";
        }
        file << item.key << " = " << item.value << "\n";
    }
    file << "\n"; // 添加一个换行符作为分隔
}

// 函数：获取用户输入
std::string getUserInput(const std::string& prompt, const std::string& defaultValue) {
    std::string input;
    std::cout << prompt << " (default: " << defaultValue << "): ";
    std::getline(std::cin, input);
    return input.empty() ? defaultValue : input;
}

int main() {
    std::ofstream file;
    std::string filename = "Damage.cc";

    // 打开文件
    file.open(filename);
    if (!file.is_open()) {
        std::cerr << "Error: Unable to open file " << filename << std::endl;
        return 1;
    }

    // 定义默认配置项
    std::vector<ConfigItem> defaultConfig = {
        {"Player", "damage", "999999"},
        {"Player", "helmet_damage", "999999"},
        {"Player", "armor_damage", "999999"},
        {"Player", "armor_penetration", "999999.9"},
        {"Weapon", "headshot_damage", "999999"},
        {"Weapon", "gun_damage", "999999"},
        {"Weapon", "melee_damage", "999999"},
        {"Weapon", "ranged_damage", "999999"},
        {"Map", "map_type", "subway"},
        {"Map", "applicable_maps", "all"},
        {"Armor", "applicable_armor", "all"},
        {"Armor", "armor_penetration", "999999.9"},
        {"Helmet", "applicable_helmets", "all"},
        {"Helmet", "helmet_damage_reduction", "999999.9"},
        {"PlayerType", "applicable_players", "all"},
        {"GameMode", "applicable_modes", "all"}
    };

    // 提示用户是否要自定义配置
    std::cout << "Do you want to customize the configuration? (yes/no): ";
    std::string customize;
    std::getline(std::cin, customize);

    if (customize == "yes") {
        std::map<std::string, std::string> customValues;
        for (const auto& item : defaultConfig) {
            customValues[item.key] = getUserInput(item.key, item.value);
        }

        // 使用用户输入生成配置文件
        for (const auto& item : defaultConfig) {
            if (!item.section.empty() && (customValues.begin()->first != item.key)) {
                file << "[" << item.section << "]\n";
            }
            file << item.key << " = " << customValues[item.key] << "\n";
        }
    } else {
        // 使用默认配置生成文件
        generateConfig(file, defaultConfig);
    }

    // 关闭文件
    file.close();
    std::cout << "Configuration file " << filename << " has been generated successfully.\n";

    return 0;
}