#include <iostream>
#include <fstream>
#include <string>
#include <map>
#include <vector>

// 定义配置项结构
struct ConfigItem {
    std::string section;
    std::string key;
    std::string defaultValue;
};

// 函数：获取用户输入
std::string getUserInput(const std::string& prompt, const std::string& defaultValue) {
    std::string input;
    std::cout << prompt << " (default: " << defaultValue << "): ";
    std::getline(std::cin, input);
    return input.empty() ? defaultValue : input;
}

// 函数：生成配置文件
void generateConfig(const std::string& filename, const std::vector<ConfigItem>& configItems) {
    std::ofstream file(filename);
    if (!file.is_open()) {
        std::cerr << "Error: Unable to open file " << filename << std::endl;
        return;
    }

    std::string lastSection = "";
    for (const auto& item : configItems) {
        if (item.section != lastSection) {
            file << "[" << item.section << "]\n";
            lastSection = item.section;
        }
        file << item.key << " = " << item.defaultValue << "\n";
    }
    file.close();
    std::cout << "Configuration file " << filename << " has been generated successfully.\n";
}

// 函数：生成自定义配置文件
void generateCustomConfig(const std::string& filename, const std::vector<ConfigItem>& configItems) {
    std::ofstream file(filename);
    if (!file.is_open()) {
        std::cerr << "Error: Unable to open file " << filename << std::endl;
        return;
    }

    std::string lastSection = "";
    for (const auto& item : configItems) {
        if (item.section != lastSection) {
            file << "[" << item.section << "]\n";
            lastSection = item.section;
        }
        std::string value = getUserInput(item.key, item.defaultValue);
        file << item.key << " = " << value << "\n";
    }
    file.close();
    std::cout << "Custom configuration file " << filename << " has been generated successfully.\n";
}

int main() {
    std::string filename = "DamageConfig.ini";

    // 定义默认配置项
    std::vector<ConfigItem> configItems = {
        {"Player", "damage", "999999"},
        {"Weapon", "headshot_damage", "999999"},
        {"Weapon", "gun_damage", "999999"},
        {"Weapon", "armor_penetration", "999999.9"},
        {"Weapon", "melee_damage", "999999"},
        {"Weapon", "ranged_damage", "999999"},
        {"Armor", "helmet_damage", "999999"},
        {"Armor", "vest_damage", "999999"},
        {"Armor", "armor_penetration", "999999.9"},
        {"Map", "name", "Subway"},
        {"Map", "description", "All Subway maps"},
        {"Mode", "name", "All modes"},
        {"Mode", "description", "Applicable to all game modes"},
        {"PlayerType", "name", "All players"},
        {"PlayerType", "description", "Applicable to all player types"}
    };

    // 提示用户是否要自定义配置
    std::cout << "Do you want to customize the configuration? (yes/no): ";
    std::string customize;
    std::getline(std::cin, customize);

    if (customize == "yes") {
        generateCustomConfig(filename, configItems);
    } else {
        generateConfig(filename, configItems);
    }

    return 0;
}