#include "CoreMinimal.h"
#include "Engine/GameInstance.h"
#include "EnhancedAimAssistGameInstance.generated.h"

UCLASS()
class YOURPROJECT_API UEnhancedAimAssistGameInstance : public UGameInstance
{
    GENERATED_BODY()

public:
    virtual void Init() override;

private:
    bool bEnableAimAssist;
    FString TargetType;
    bool bIgnoreSelf;
    float AimAssistRange; // 新增瞄准辅助范围的变量

    // 新增函数，用于实现超级大范围瞄准辅助
    void EnableSuperWideAimAssist();
};

void UEnhancedAimAssistGameInstance::Init()
{
    Super::Init();

    // 读取配置文件
    FString ConfigPath = FPaths::ProjectConfigDir() + TEXT("EnhancedAimAssist.ini");
    TSharedPtr<IPlatformFile> PlatformFile = FPlatformFileManager::Get().GetPlatformFile();
    if (PlatformFile->Exists(*ConfigPath))
    {
        FString FileContent;
        if (FFileHelper::LoadFileToString(FileContent, *ConfigPath))
        {
            IniParseSection(ConfigPath, "EnhancedAimAssist", FileContent);
        }
    }

    // 应用配置
    if (bEnableAimAssist)
    {
        // 启用增强瞄准辅助功能
        if (TargetType == "Head")
        {
            // 实现瞄准辅助功能，使准星吸附其他玩家的头部
            EnableSuperWideAimAssist(); // 调用超级大范围瞄准辅助功能
        }
    }
}

bool UEnhancedAimAssistGameInstance::IniParseSection(const FString& FilePath, const FString& SectionName, const FString& Content)
{
    TArray<FString> Lines;
    Content.ParseIntoArray(Lines, TEXT("\n"), true);

    for (const FString& Line : Lines)
    {
        if (!Line.IsEmpty())
        {
            int32 EqualIndex = Line.Find(TEXT("="));
            if (EqualIndex != INDEX_NONE)
            {
                FString Key = Line.Mid(0, EqualIndex).Trim();
                FString Value = Line.Mid(EqualIndex + 1).Trim();

                if (Key.Equals("EnableAimAssist"))
                {
                    bEnableAimAssist = FCString::ToBool(*Value);
                }
                else if (Key.Equals("TargetType"))
                {
                    TargetType = Value;
                }
                else if (Key.Equals("IgnoreSelf"))
                {
                    bIgnoreSelf = FCString::ToBool(*Value);
                }
                else if (Key.Equals("AimAssistRange")) // 新增读取瞄准辅助范围的配置
                {
                    AimAssistRange = FCString::Atof(*Value);
                }
            }
        }
    }

    return true;
}

void UEnhancedAimAssistGameInstance::EnableSuperWideAimAssist()
{
    // 实现超级大范围瞄准辅助功能
    // 这里可以根据 AimAssistRange 来调整瞄准辅助的范围
    // 例如，将瞄准辅助的范围设置为一个很大的值
    AimAssistRange = 10000.0f; // 设置一个非常大的范围值，单位为游戏世界单位

    // 在这里可以添加代码来实现具体的瞄准辅助逻辑
    // 例如，扫描范围内所有玩家的头部，并将准星吸附到最近的目标上
    // 这部分逻辑需要根据你的游戏的具体实现来编写
    UE_LOG(LogTemp, Log, TEXT("Super Wide Aim Assist Enabled with range: %f"), AimAssistRange);
}