import java.awt.*;
import java.awt.geom.Point2D;
import java.util.ArrayList;
import java.util.List;

// 子弹类
class Bullet {
    private Point2D position; // 子弹位置
    private double speed; // 子弹速度
    private double range; // 子弹追踪范围（超大范围）

    public Bullet(double x, double y, double speed, double range) {
        this.position = new Point2D.Double(x, y);
        this.speed = speed;
        this.range = range;
    }

    public Point2D getPosition() {
        return position;
    }

    public void setPosition(Point2D position) {
        this.position = position;
    }

    public double getSpeed() {
        return speed;
    }

    public double getRange() {
        return range;
    }

    // 更新子弹位置
    public void update(double dx, double dy) {
        position.setLocation(position.getX() + dx, position.getY() + dy);
    }
}

// 目标类
class Target {
    private Point2D position; // 目标位置

    public Target(double x, double y) {
        this.position = new Point2D.Double(x, y);
    }

    public Point2D getPosition() {
        return position;
    }
}

// A*算法实现（简化版）
class AStarPathfinding {
    private static final int[][] DIRECTIONS = {{1, 0}, {0, 1}, {-1, 0}, {0, -1}};
    private int[][] grid; // 地图网格
    private boolean[][] visited;

    public AStarPathfinding(int[][] grid) {
        this.grid = grid;
        this.visited = new boolean[grid.length][grid[0].length];
    }

    public List<Point> findPath(int startX, int startY, int goalX, int goalY) {
        List<Point> openList = new ArrayList<>();
        openList.add(new Point(startX, startY));
        while (!openList.isEmpty()) {
            Point current = openList.remove(0);
            if (current.x == goalX && current.y == goalY) {
                return reconstructPath(startX, startY, goalX, goalY);
            }
            visited[current.x][current.y] = true;
            for (int[] direction : DIRECTIONS) {
                int newX = current.x + direction[0];
                int newY = current.y + direction[1];
                if (isValidMove(newX, newY)) {
                    openList.add(new Point(newX, newY));
                }
            }
        }
        return Collections.emptyList();
    }

    private boolean isValidMove(int x, int y) {
        return x >= 0 && x < grid.length && y >= 0 && y < grid[0].length && grid[x][y] == 0;
    }

    private List<Point> reconstructPath(int startX, int startY, int goalX, int goalY) {
        List<Point> path = new ArrayList<>();
        path.add(new Point(goalX, goalY));
        return path; // 简化版，直接返回目标点
    }
}

// 主程序
public class SuperBulletTracking {
    public static void main(String[] args) {
        // 创建地图网格（0表示可通过，1表示障碍）
        int[][] grid = {
                {0, 0, 0, 0, 0},
                {0, 1, 1, 0, 0},
                {0, 0, 0, 1, 0},
                {0, 1, 0, 0, 0},
                {0, 0, 0, 0, 0}
        };

        // 创建子弹和目标
        Bullet bullet = new Bullet(0, 0, 5, 100); // 子弹初始位置(0,0)，速度5，追踪范围100
        Target target = new Target(4, 4); // 目标位置(4,4)

        // 使用A*算法找到路径
        AStarPathfinding pathfinder = new AStarPathfinding(grid);
        List<Point> path = pathfinder.findPath((int) bullet.getPosition().getX(), (int) bullet.getPosition().getY(),
                (int) target.getPosition().getX(), (int) target.getPosition().getY());

        // 更新子弹位置以追踪目标
        if (!path.isEmpty()) {
            Point nextPoint = path.get(0);
            double dx = nextPoint.x - bullet.getPosition().getX();
            double dy = nextPoint.y - bullet.getPosition().getY();
            double distance = Math.sqrt(dx * dx + dy * dy);
            if (distance > bullet.getSpeed()) {
                dx = dx / distance * bullet.getSpeed();
                dy = dy / distance * bullet.getSpeed();
            }
            bullet.update(dx, dy);
        }

        // 输出子弹和目标位置
        System.out.println("子弹位置: " + bullet.getPosition());
        System.out.println("目标位置: " + target.getPosition());
    }
}