import java.util.Random;

// 子弹类
class Bullet {
    private int damage; // 子弹伤害

    public Bullet(int damage) {
        this.damage = damage;
    }

    public int getDamage() {
        return damage;
    }
}

// 枪械类
class Gun {
    private String model; // 枪械型号
    private int baseDamage; // 基础伤害
    private Clip clip; // 弹夹

    public Gun(String model, int baseDamage) {
        this.model = model;
        this.baseDamage = baseDamage;
        this.clip = new Clip();
    }

    // 增强伤害
    public void enhanceDamage() {
        // 增加基础伤害
        this.baseDamage += 10;
        System.out.println("AKM伤害增强完成！新的基础伤害: " + this.baseDamage);
    }

    // 装填子弹
    public void loadClip() {
        for (int i = 0; i < 30; i++) {
            clip.addBullet(new Bullet(baseDamage));
        }
    }

    // 射击
    public void shoot(Player enemy) {
        if (clip.isEmpty()) {
            System.out.println("弹夹为空，无法射击！");
            return;
        }
        Bullet bullet = clip.popBullet();
        enemy.takeDamage(bullet.getDamage());
        System.out.println("射击成功，对敌人造成 " + bullet.getDamage() + " 点伤害。");
    }
}

// 弹夹类
class Clip {
    private Bullet[] bullets = new Bullet[30];
    private int count = 0;

    public void addBullet(Bullet bullet) {
        if (count < bullets.length) {
            bullets[count++] = bullet;
        }
    }

    public boolean isEmpty() {
        return count == 0;
    }

    public Bullet popBullet() {
        if (count > 0) {
            return bullets[--count];
        }
        return null;
    }
}

// 玩家类
class Player {
    private String name;
    private int health;

    public Player(String name, int health) {
        this.name = name;
        this.health = health;
    }

    public void takeDamage(int damage) {
        health -= damage;
        if (health <= 0) {
            System.out.println(name + " 已被击败！");
        } else {
            System.out.println(name + " 剩余血量: " + health);
        }
    }
}

// 主程序
public class AKMEnhancement {
    public static void main(String[] args) {
        // 创建AKM枪械
        Gun akm = new Gun("AKM", 40); // 基础伤害为40
        akm.enhanceDamage(); // 增强伤害
        akm.loadClip(); // 装填弹夹

        // 创建玩家
        Player player = new Player("敌人", 100); // 敌人初始血量为100

        // 模拟射击
        Random random = new Random();
        for (int i = 0; i < 5; i++) {
            akm.shoot(player);
            if (player.health <= 0) {
                break;
            }
        }
    }
}