import java.awt.*;
import java.awt.event.*;
import java.util.ArrayList;
import java.util.List;
import javax.swing.*;

// 子弹类
class Bullet {
    private int x, y; // 子弹位置
    private int speed; // 子弹速度
    private boolean isVisible; // 子弹是否可见

    public Bullet(int startX, int startY) {
        x = startX;
        y = startY;
        speed = 10; // 子弹速度
        isVisible = true;
    }

    public void update(int targetX, int targetY) {
        // 简单的追踪逻辑：向目标位置移动
        if (isVisible) {
            if (x < targetX) x += speed;
            if (x > targetX) x -= speed;
            if (y < targetY) y += speed;
            if (y > targetY) y -= speed;
        }
    }

    public void draw(Graphics g) {
        if (isVisible) {
            g.setColor(Color.RED);
            g.fillOval(x, y, 10, 10); // 绘制子弹
        }
    }

    public boolean isVisible() {
        return isVisible;
    }
}

// 目标类
class Target {
    private int x, y; // 目标位置

    public Target(int startX, int startY) {
        x = startX;
        y = startY;
    }

    public void update() {
        // 简单的目标移动逻辑
        x += 5;
        y += 5;
    }

    public int getX() {
        return x;
    }

    public int getY() {
        return y;
    }

    public void draw(Graphics g) {
        g.setColor(Color.GREEN);
        g.fillOval(x, y, 20, 20); // 绘制目标
    }
}

// 游戏面板
class GamePanel extends JPanel implements ActionListener, KeyListener {
    private Timer timer;
    private ArrayList<Bullet> bullets;
    private Target target;

    public GamePanel() {
        timer = new Timer(30, this); // 定时器，每30ms更新一次
        bullets = new ArrayList<>();
        target = new Target(100, 100); // 目标初始位置
        addKeyListener(this);
        setFocusable(true);
        timer.start();
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        // 更新子弹和目标的位置
        for (Bullet bullet : bullets) {
            bullet.update(target.getX(), target.getY());
        }
        target.update();
        repaint();
    }

    @Override
    protected void paintComponent(Graphics g) {
        super.paintComponent(g);
        // 绘制目标
        target.draw(g);
        // 绘制所有子弹
        for (Bullet bullet : bullets) {
            bullet.draw(g);
        }
    }

    @Override
    public void keyPressed(KeyEvent e) {
        if (e.getKeyCode() == KeyEvent.VK_SPACE) {
            // 按下空格键时发射子弹
            bullets.add(new Bullet(250, 500)); // 子弹从固定位置发射
        }
    }

    @Override
    public void keyReleased(KeyEvent e) {
    }

    @Override
    public void keyTyped(KeyEvent e) {
    }
}

// 主程序
public class SuperBulletTracking {
    public static void main(String[] args) {
        JFrame frame = new JFrame("超大子弹追踪");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setSize(600, 600);
        frame.add(new GamePanel());
        frame.setVisible(true);
    }
}