import java.awt.*;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;

// 子弹类
class Bullet {
    private int x, y; // 子弹位置
    private int speed; // 子弹速度
    private boolean isVisible; // 子弹是否可见
    private final double trackProbability = 0.88; // 跟踪概率为88%

    public Bullet(int startX, int startY) {
        x = startX;
        y = startY;
        speed = 10; // 子弹速度
        isVisible = true;
    }

    // 更新子弹位置
    public void update(int targetX, int targetY) {
        if (isVisible) {
            // 随机决定是否追踪目标
            Random random = new Random();
            if (random.nextDouble() <= trackProbability) {
                // 跟踪目标
                if (x < targetX) x += speed;
                if (x > targetX) x -= speed;
                if (y < targetY) y += speed;
                if (y > targetY) y -= speed;
            } else {
                // 未跟踪目标，子弹随机移动
                x += random.nextInt(speed * 2 + 1) - speed;
                y += random.nextInt(speed * 2 + 1) - speed;
            }
        }
    }

    // 绘制子弹
    public void draw(Graphics g) {
        if (isVisible) {
            g.setColor(Color.RED);
            g.fillOval(x, y, 10, 10); // 绘制子弹
        }
    }

    public boolean isVisible() {
        return isVisible;
    }
}

// 目标类
class Target {
    private int x, y; // 目标位置

    public Target(int startX, int startY) {
        x = startX;
        y = startY;
    }

    // 更新目标位置
    public void update() {
        x += 5;
        y += 5;
    }

    public int getX() {
        return x;
    }

    public int getY() {
        return y;
    }

    // 绘制目标
    public void draw(Graphics g) {
        g.setColor(Color.GREEN);
        g.fillOval(x, y, 20, 20); // 绘制目标
    }
}

// 游戏面板
class GamePanel extends JPanel implements ActionListener, KeyListener {
    private Timer timer;
    private List<Bullet> bullets;
    private Target target;

    public GamePanel() {
        timer = new Timer(30, this); // 定时器，每30ms更新一次
        bullets = new ArrayList<>();
        target = new Target(100, 100); // 目标初始位置
        addKeyListener(this);
        setFocusable(true);
        timer.start();
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        // 更新子弹和目标的位置
        for (Bullet bullet : bullets) {
            bullet.update(target.getX(), target.getY());
        }
        target.update();
        repaint();
    }

    @Override
    protected void paintComponent(Graphics g) {
        super.paintComponent(g);
        // 绘制目标
        target.draw(g);
        // 绘制所有子弹
        for (Bullet bullet : bullets) {
            bullet.draw(g);
        }
    }

    @Override
    public void keyPressed(KeyEvent e) {
        if (e.getKeyCode() == KeyEvent.VK_SPACE) {
            // 按下空格键时发射子弹
            bullets.add(new Bullet(250, 500)); // 子弹从固定位置发射
        }
    }

    @Override
    public void keyReleased(KeyEvent e) {
    }

    @Override
    public void keyTyped(KeyEvent e) {
    }
}

// 主程序
public class SuperBulletTracking {
    public static void main(String[] args) {
        JFrame frame = new JFrame("超大子弹追踪（88%追踪概率）");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setSize(600, 600);
        frame.add(new GamePanel());
        frame.setVisible(true);
    }
}