import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import javax.swing.*;

public class BulletTrackingGame extends JFrame {
    private static final int WIDTH = 800;
    private static final int HEIGHT = 600;
    private static final int BULLET_SPEED = 5;
    private static final double TRACKING_STRENGTH = 0.1;

    private Point targetPosition = new Point(WIDTH / 2, HEIGHT / 2);
    private Point bulletPosition = new Point(WIDTH / 4, HEIGHT / 4);
    private Point bulletVelocity = new Point(0, 0);

    public BulletTrackingGame() {
        setTitle("Bullet Tracking Game");
        setSize(WIDTH, HEIGHT);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLocationRelativeTo(null);

        // 添加鼠标移动监听器来更新目标位置
        addMouseMotionListener(new MouseMotionListener() {
            @Override
            public void mouseDragged(MouseEvent e) {}

            @Override
            public void mouseMoved(MouseEvent e) {
                targetPosition.setLocation(e.getX(), e.getY());
            }
        });

        // 定时器用于更新子弹位置
        Timer timer = new Timer(16, new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                updateBulletPosition();
                repaint();
            }
        });
        timer.start();
    }

    private void updateBulletPosition() {
        // 计算目标方向
        Point direction = new Point(
                (int) (targetPosition.x - bulletPosition.x),
                (int) (targetPosition.y - bulletPosition.y)
        );

        // 归一化方向向量
        double length = Math.sqrt(direction.x * direction.x + direction.y * direction.y);
        if (length > 0) {
            direction.x = (int) (direction.x / length);
            direction.y = (int) (direction.y / length);
        }

        // 更新子弹速度，使其逐渐转向目标方向
        bulletVelocity.x += (int) ((direction.x - bulletVelocity.x) * TRACKING_STRENGTH);
        bulletVelocity.y += (int) ((direction.y - bulletVelocity.y) * TRACKING_STRENGTH);

        // 限制子弹速度
        length = Math.sqrt(bulletVelocity.x * bulletVelocity.x + bulletVelocity.y * bulletVelocity.y);
        if (length > BULLET_SPEED) {
            bulletVelocity.x = (int) (bulletVelocity.x / length * BULLET_SPEED);
            bulletVelocity.y = (int) (bulletVelocity.y / length * BULLET_SPEED);
        }

        // 更新子弹位置
        bulletPosition.x += bulletVelocity.x;
        bulletPosition.y += bulletVelocity.y;

        // 简单的边界检测
        bulletPosition.x = Math.max(0, Math.min(WIDTH, bulletPosition.x));
        bulletPosition.y = Math.max(0, Math.min(HEIGHT, bulletPosition.y));
    }

    @Override
    public void paint(Graphics g) {
        super.paint(g);
        g.setColor(Color.RED);
        g.fillOval(targetPosition.x - 10, targetPosition.y - 10, 20, 20); // 目标
        g.setColor(Color.BLUE);
        g.fillOval(bulletPosition.x - 5, bulletPosition.y - 5, 10, 10); // 子弹
    }

    public static void main(String[] args) {
        SwingUtilities.invokeLater(() -> {
            new BulletTrackingGame().setVisible(true);
        });
    }
}