import java.awt.image.BufferedImage;
import java.util.Random;

// 英雄机类
public class Hero extends FlyingObject {
    private int life;               // 生命值
    private int doubleFire;         // 火力值
    private BufferedImage[] images; // 图片切换数组
    private int index;              // 协助切换图片的索引

    public Hero() {                 // 构造方法
        image = ShootGame.hero0;    // 图片初始化
        width = image.getWidth();
        height = image.getHeight();
        x = 150;                    // 初始位置
        y = 400;
        life = 3;                   // 初始生命值
        doubleFire = 0;             // 初始火力值
        images = new BufferedImage[]{ShootGame.hero0, ShootGame.hero1}; // 图片切换
        index = 0;
    }

    public void step() {            // 走步方法
        image = images[index++ / 10 % images.length]; // 每100毫秒切换一次图片
    }

    public Bullet[] shoot() {       // 发射子弹方法
        int xStep = this.width / 4; // 子弹发射间隔
        int yStep = 20;             // 子弹发射的y轴偏移量

        // 双倍火力逻辑
        if (doubleFire > 0) {
            Bullet[] bs = new Bullet[2]; // 双倍火力发射两颗子弹
            bs[0] = new Bullet(this.x + xStep * 1, this.y - yStep); // 第一颗子弹位置
            bs[1] = new Bullet(this.x + xStep * 3, this.y - yStep); // 第二颗子弹位置
            doubleFire -= 2;       // 发射一次双倍火力，火力值减少
            return bs;
        } else {
            // 单倍火力逻辑
            Bullet[] bs = new Bullet[1];
            bs[0] = new Bullet(this.x + xStep * 2, this.y - yStep); // 单倍火力发射一颗子弹
            return bs;
        }
    }

    public void moveTo(int x, int y) { // 英雄机随鼠标移动
        this.x = x - this.width / 2;
        this.y = y - this.height / 2;
    }

    public boolean outOfBounds() {    // 英雄机永不越界
        return false;
    }

    public void addLife() {           // 生命值增加
        life++;
    }

    public int getLife() {            // 获取生命值
        return life;
    }

    public void subtractLife() {      // 生命值减少
        life--;
    }

    public void addDoubleFir() {      // 增加双倍火力
        doubleFire += 40;
    }

    public void clearDoubleFire() {   // 清除双倍火力
        doubleFire = 0;
    }

    public boolean hit(FlyingObject other) { // 英雄机与敌人的碰撞检测
        int x1 = other.x - this.width / 2;
        int x2 = other.x + other.width + this.width / 2;
        int y1 = other.y - this.height / 2;
        int y2 = other.y + other.height + this.height / 2;
        int x = this.x + this.width / 2;
        int y = this.y + this.height / 2;
        return x > x1 && x < x2 && y > y1 && y < y2;
    }
}