import java.awt.geom.Point2D;

public class Bullet {
    private Point2D position; // 子弹当前位置
    private Point2D target; // 目标位置
    private double speed; // 子弹速度

    public Bullet(double startX, double startY, double targetX, double targetY, double speed) {
        this.position = new Point2D.Double(startX, startY);
        this.target = new Point2D.Double(targetX, targetY);
        this.speed = speed;
    }

    // 更新子弹位置
    public void update() {
        if (position.distance(target) > speed) {
            // 计算方向向量
            double dx = target.getX() - position.getX();
            double dy = target.getY() - position.getY();
            double distance = Math.sqrt(dx * dx + dy * dy);

            // 计算单位方向向量
            double unitX = dx / distance;
            double unitY = dy / distance;

            // 更新位置
            position.setLocation(position.getX() + unitX * speed, position.getY() + unitY * speed);
        } else {
            // 如果距离小于速度，直接到达目标
            position.setLocation(target.getX(), target.getY());
        }
    }

    // 获取子弹当前位置
    public Point2D getPosition() {
        return position;
    }

    // 检查是否到达目标
    public boolean hasReachedTarget() {
        return position.distance(target) <= 0.01; // 允许一个小的误差范围
    }

    public static void main(String[] args) {
        Bullet bullet = new Bullet(0, 0, 100, 100, 5); // 子弹从(0,0)出发，目标是(100,100)，速度为5

        while (!bullet.hasReachedTarget()) {
            bullet.update();
            System.out.println("子弹位置: " + bullet.getPosition());
        }

        System.out.println("子弹到达目标！");
    }
}
