import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class BulletTracking extends JFrame {
    private static final long serialVersionUID = 1L;

    private static final int WIDTH = 800;
    private static final int HEIGHT = 600;
    private static final int BULLET_SPEED = 5;

    private Point targetPosition; // 目标位置（头部）
    private Point bulletPosition; // 子弹位置
    private boolean isFiring = false;

    public BulletTracking() {
        super("Bullet Tracking Example");
        setSize(WIDTH, HEIGHT);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setResizable(false);

        // 初始化目标和子弹位置
        targetPosition = new Point(WIDTH / 2, HEIGHT / 2);
        bulletPosition = new Point(WIDTH / 4, HEIGHT / 4);

        // 添加鼠标监听器来移动目标
        addMouseListener(new MouseAdapter() {
            @Override
            public void mouseClicked(MouseEvent e) {
                targetPosition.setLocation(e.getX(), e.getY());
            }
        });

        // 添加键盘监听器来发射子弹
        addKeyListener(new KeyAdapter() {
            @Override
            public void keyPressed(KeyEvent e) {
                if (e.getKeyCode() == KeyEvent.VK_SPACE) {
                    isFiring = true;
                }
            }
        });

        // 启动游戏循环
        new Timer(16, new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                updateBulletPosition();
                repaint();
            }
        }).start();
    }

    private void updateBulletPosition() {
        if (isFiring) {
            // 计算目标和子弹之间的向量
            double dx = targetPosition.x - bulletPosition.x;
            double dy = targetPosition.y - bulletPosition.y;
            double distance = Math.sqrt(dx * dx + dy * dy);

            // 如果子弹接近目标，停止追踪
            if (distance < BULLET_SPEED) {
                bulletPosition.setLocation(targetPosition);
                isFiring = false;
            } else {
                // 更新子弹位置
                bulletPosition.x += (int) (dx / distance * BULLET_SPEED);
                bulletPosition.y += (int) (dy / distance * BULLET_SPEED);
            }
        }
    }

    @Override
    public void paint(Graphics g) {
        super.paint(g);
        g.setColor(Color.RED);
        g.fillOval(targetPosition.x - 20, targetPosition.y - 20, 40, 40); // 绘制目标（头部）
        g.setColor(Color.BLUE);
        g.fillOval(bulletPosition.x - 10, bulletPosition.y - 10, 20, 20); // 绘制子弹
    }

    public static void main(String[] args) {
        SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
                new BulletTracking().setVisible(true);
            }
        });
    }
}