import javafx.animation.KeyFrame;
import javafx.animation.Timeline;
import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.layout.Pane;
import javafx.scene.paint.Color;
import javafx.scene.shape.Circle;
import javafx.stage.Stage;
import javafx.util.Duration;

public class GrowingHeadTracking extends Application {
    private static final int WIDTH = 800;
    private static final int HEIGHT = 600;
    private static final int BULLET_SPEED = 5;

    private Circle head; // 头部模型
    private Circle bullet; // 子弹
    private boolean isFiring = false;

    @Override
    public void start(Stage primaryStage) {
        // 创建一个Pane作为根节点
        Pane root = new Pane();

        // 创建头部模型（圆形）
        head = new Circle(100, 100, 50); // x, y, radius
        head.setFill(Color.BLUE); // 设置颜色
        root.getChildren().add(head);

        // 创建子弹（圆形）
        bullet = new Circle(50, 50, 10); // x, y, radius
        bullet.setFill(Color.RED); // 设置颜色
        root.getChildren().add(bullet);

        // 创建一个场景
        Scene scene = new Scene(root, WIDTH, HEIGHT);

        // 设置舞台
        primaryStage.setTitle("Growing Head with Bullet Tracking");
        primaryStage.setScene(scene);
        primaryStage.show();

        // 添加鼠标监听器来移动头部
        scene.setOnMouseMoved(event -> {
            head.setCenterX(event.getX());
            head.setCenterY(event.getY());
        });

        // 添加键盘监听器来发射子弹
        scene.setOnKeyPressed(event -> {
            if (event.getCode() == javafx.scene.input.KeyCode.SPACE) {
                isFiring = true;
            }
        });

        // 创建一个时间线来实现动画效果
        Timeline timeline = new Timeline(new KeyFrame(Duration.millis(16), event -> {
            if (isFiring) {
                // 更新子弹位置以追踪头部
                updateBulletPosition();
            }
        }));
        timeline.setCycleCount(Timeline.INDEFINITE);
        timeline.play();

        // 创建一个时间线来让头部逐渐变大
        Timeline growTimeline = new Timeline(new KeyFrame(Duration.millis(50), event -> {
            // 每次更新时，增加头部的半径
            head.setRadius(head.getRadius() + 1);

            // 如果头部变得太大，可以停止动画
            if (head.getRadius() > 200) {
                growTimeline.stop();
            }
        }));
        growTimeline.setCycleCount(Timeline.INDEFINITE);
        growTimeline.play();
    }

    private void updateBulletPosition() {
        // 计算头部和子弹之间的向量
        double dx = head.getCenterX() - bullet.getCenterX();
        double dy = head.getCenterY() - bullet.getCenterY();
        double distance = Math.sqrt(dx * dx + dy * dy);

        // 如果子弹接近头部，停止追踪
        if (distance < BULLET_SPEED) {
            bullet.setCenterX(head.getCenterX());
            bullet.setCenterY(head.getCenterY());
            isFiring = false;
        } else {
            // 更新子弹位置
            bullet.setCenterX(bullet.getCenterX() + dx / distance * BULLET_SPEED);
            bullet.setCenterY(bullet.getCenterY() + dy / distance * BULLET_SPEED);
        }
    }

    public static void main(String[] args) {
        launch(args);
    }
}