public class Particle {
    private float x, y;
    private float vx, vy;
    private float lifeTime;

    public Particle(float x, float y, float vx, float vy, float lifeTime) {
        this.x = x;
        this.y = y;
        this.vx = vx;
        this.vy = vy;
        this.lifeTime = lifeTime;
    }

    public void update(float deltaTime) {
        x += vx * deltaTime;
        y += vy * deltaTime;
        lifeTime -= deltaTime;
    }

    public boolean isAlive() {
        return lifeTime > 0;
    }
}

public class ParticleSystem {
    private List<Particle> particles;

    public ParticleSystem() {
        particles = new ArrayList<>();
    }

    public void emit(float x, float y, int count) {
        for (int i = 0; i < count; i++) {
            float vx = (float) (Math.random() * 2 - 1);
            float vy = (float) (Math.random() * 2 - 1);
            particles.add(new Particle(x, y, vx, vy, 1.0f));
        }
    }

    public void update(float deltaTime) {
        Iterator<Particle> it = particles.iterator();
        while (it.hasNext()) {
            Particle p = it.next();
            p.update(deltaTime);
            if (!p.isAlive()) {
                it.remove();
            }
        }
    }

    public void paint(Graphics g) {
        for (Particle p : particles) {
            g.fillRect((int) p.x, (int) p.y, 2, 2);
        }
    }
}