import java.util.HashMap;
import java.util.Map;

// 定义角色属性类
class CharacterAttributes {
    private Map<String, Integer> attributes = new HashMap<>();

    // 构造函数，初始化角色属性
    public CharacterAttributes() {
        attributes.put("Attack", 100); // 初始攻击力
        attributes.put("Defense", 50); // 初始防御力
        attributes.put("DamageReduction", 0); // 初始减伤
        attributes.put("Health", 1000); // 初始生命值
    }

    // 获取属性值
    public int getAttribute(String key) {
        return attributes.getOrDefault(key, 0);
    }

    // 设置属性值
    public void setAttribute(String key, int value) {
        attributes.put(key, value);
    }

    // 计算实际受到的伤害
    public int calculateDamageTaken(int incomingDamage) {
        int defense = getAttribute("Defense");
        int damageReduction = getAttribute("DamageReduction");
        int actualDamage = incomingDamage - defense - damageReduction;
        return Math.max(actualDamage, 0); // 伤害不能小于0
    }

    // 受到伤害时更新生命值
    public void takeDamage(int incomingDamage) {
        int actualDamage = calculateDamageTaken(incomingDamage);
        int currentHealth = getAttribute("Health");
        setAttribute("Health", currentHealth - actualDamage);
        System.out.println("Character took " + actualDamage + " damage. Health remaining: " + getAttribute("Health"));
    }
}

// 测试类
public class CharacterSystem {
    public static void main(String[] args) {
        // 创建角色
        CharacterAttributes character = new CharacterAttributes();

        // 输出初始属性
        System.out.println("Initial Attributes:");
        System.out.println("Attack: " + character.getAttribute("Attack"));
        System.out.println("Defense: " + character.getAttribute("Defense"));
        System.out.println("DamageReduction: " + character.getAttribute("DamageReduction"));
        System.out.println("Health: " + character.getAttribute("Health"));

        // 增加减伤
        character.setAttribute("DamageReduction", 20);
        System.out.println("Updated DamageReduction: " + character.getAttribute("DamageReduction"));

        // 角色受到伤害
        character.takeDamage(150);

        // 再次增加防御力
        character.setAttribute("Defense", 70);
        System.out.println("Updated Defense: " + character.getAttribute("Defense"));

        // 角色再次受到伤害
        character.takeDamage(150);
    }
}
