import java.io.*;
import java.util.Scanner;

public class AuxiliaryAimingConfig {
    private boolean auxiliaryAimingEnabled;
    private String auxiliaryAimingDetectionRange;
    private String auxiliaryAimingTrackingSpeed;
    private String assistTargetArea;
    private String jumpBehavior;

    // 默认构造函数
    public AuxiliaryAimingConfig() {
        auxiliaryAimingEnabled = true;
        auxiliaryAimingDetectionRange = "MAX";
        auxiliaryAimingTrackingSpeed = "MAX";
        assistTargetArea = "Head";
        jumpBehavior = "Viscous self-sighting";
    }

    // 设置和获取方法
    public void setAuxiliaryAimingEnabled(boolean auxiliaryAimingEnabled) {
        this.auxiliaryAimingEnabled = auxiliaryAimingEnabled;
    }

    public boolean isAuxiliaryAimingEnabled() {
        return auxiliaryAimingEnabled;
    }

    public void setAuxiliaryAimingDetectionRange(String auxiliaryAimingDetectionRange) {
        this.auxiliaryAimingDetectionRange = auxiliaryAimingDetectionRange;
    }

    public String getAuxiliaryAimingDetectionRange() {
        return auxiliaryAimingDetectionRange;
    }

    public void setAuxiliaryAimingTrackingSpeed(String auxiliaryAimingTrackingSpeed) {
        this.auxiliaryAimingTrackingSpeed = auxiliaryAimingTrackingSpeed;
    }

    public String getAuxiliaryAimingTrackingSpeed() {
        return auxiliaryAimingTrackingSpeed;
    }

    public void setAssistTargetArea(String assistTargetArea) {
        this.assistTargetArea = assistTargetArea;
    }

    public String getAssistTargetArea() {
        return assistTargetArea;
    }

    public void setJumpBehavior(String jumpBehavior) {
        this.jumpBehavior = jumpBehavior;
    }

    public String getJumpBehavior() {
        return jumpBehavior;
    }

    // 保存配置到文件
    public void saveConfig(String filename) throws IOException {
        try (BufferedWriter writer = new BufferedWriter(new FileWriter(filename))) {
            writer.write("[Adjustment of auxiliary aiming configuration]\n");
            writer.write("Auxiliary aiming enabled state=" + auxiliaryAimingEnabled + "\n");
            writer.write("Auxiliary aiming detection range=" + auxiliaryAimingDetectionRange + "\n");
            writer.write("Auxiliary aiming and tracking speed=" + auxiliaryAimingTrackingSpeed + "\n");
            writer.write("Assist in targeting and striking the target area=" + assistTargetArea + "\n");
            writer.write("Jump after hitting the enemy=" + jumpBehavior + "\n");
        }
    }

    // 从文件加载配置
    public void loadConfig(String filename) throws IOException {
        try (BufferedReader reader = new BufferedReader(new FileReader(filename))) {
            String line;
            while ((line = reader.readLine()) != null) {
                line = line.trim();
                if (line.startsWith("Auxiliary aiming enabled state")) {
                    auxiliaryAimingEnabled = Boolean.parseBoolean(line.split("=")[1].trim());
                } else if (line.startsWith("Auxiliary aiming detection range")) {
                    auxiliaryAimingDetectionRange = line.split("=")[1].trim();
                } else if (line.startsWith("Auxiliary aiming and tracking speed")) {
                    auxiliaryAimingTrackingSpeed = line.split("=")[1].trim();
                } else if (line.startsWith("Assist in targeting and striking the target area")) {
                    assistTargetArea = line.split("=")[1].trim();
                } else if (line.startsWith("Jump after hitting the enemy")) {
                    jumpBehavior = line.split("=")[1].trim();
                }
            }
        }
    }

    // 主程序
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        AuxiliaryAimingConfig config = new AuxiliaryAimingConfig();

        System.out.println("Do you want to load existing configuration? (yes/no): ");
        String loadConfig = scanner.nextLine().trim();

        if (loadConfig.equalsIgnoreCase("yes")) {
            System.out.println("Enter the path to the configuration file: ");
            String filePath = scanner.nextLine().trim();
            try {
                config.loadConfig(filePath);
                System.out.println("Configuration loaded successfully.");
            } catch (IOException e) {
                System.out.println("Error loading configuration: " + e.getMessage());
            }
        } else {
            System.out.println("Enter auxiliary aiming enabled state (true/false): ");
            config.setAuxiliaryAimingEnabled(scanner.nextBoolean());
            scanner.nextLine(); // 消耗换行符

            System.out.println("Enter auxiliary aiming detection range (e.g., MAX): ");
            config.setAuxiliaryAimingDetectionRange(scanner.nextLine().trim());

            System.out.println("Enter auxiliary aiming and tracking speed (e.g., MAX): ");
            config.setAuxiliaryAimingTrackingSpeed(scanner.nextLine().trim());

            System.out.println("Enter assist in targeting and striking the target area (e.g., Head): ");
            config.setAssistTargetArea(scanner.nextLine().trim());

            System.out.println("Enter jump behavior after hitting the enemy (e.g., Viscous self-sighting): ");
            config.setJumpBehavior(scanner.nextLine().trim());
        }

        System.out.println("Do you want to save the current configuration? (yes/no): ");
        String saveConfig = scanner.nextLine().trim();

        if (saveConfig.equalsIgnoreCase("yes")) {
            System.out.println("Enter the path to save the configuration file: ");
            String saveFilePath = scanner.nextLine().trim();
            try {
                config.saveConfig(saveFilePath);
                System.out.println("Configuration saved successfully.");
            } catch (IOException e) {
                System.out.println("Error saving configuration: " + e.getMessage());
            }
        }

        scanner.close();
    }
}