import java.util.Random;
import java.util.Scanner;

public class SuperEnhancedHipFireGame {
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        Player player = new Player();

        System.out.println("Welcome to the Super Enhanced Hip Fire Game!");
        System.out.println("Enter '1' to Hip Fire, '2' to Aim and Shoot, '3' to Use Special Skill, '4' to Check Equipment, '0' to Exit.");

        while (true) {
            System.out.print("Your choice: ");
            int choice = scanner.nextInt();

            if (choice == 0) {
                System.out.println("Exiting game. Goodbye!");
                break;
            } else if (choice == 1) {
                player.enhancedHipFire();
            } else if (choice == 2) {
                player.aimAndShoot();
            } else if (choice == 3) {
                player.useSpecialSkill();
            } else if (choice == 4) {
                player.checkEquipment();
            } else {
                System.out.println("Invalid choice. Please try again.");
            }
        }

        scanner.close();
    }
}

class Player {
    private int hipFireAccuracy = 50; // 50% base accuracy for hip fire
    private int aimAccuracy = 90; // 90% accuracy for aimed shots
    private int enhancedAccuracyBonus = 20; // 20% bonus accuracy when enhanced
    private int enhancedDamageBonus = 5; // 5 extra damage when enhanced
    private int baseDamage = 10; // Base damage per shot
    private int specialSkillDamage = 20; // Special skill damage
    private int specialSkillCooldown = 3; // Special skill cooldown turns
    private int currentCooldown = 0; // Current cooldown turns
    private int comboCount = 0; // Combo count
    private int comboBonus = 5; // Bonus damage per combo
    private String equipment = "Basic Weapon"; // Default equipment

    public void enhancedHipFire() {
        System.out.println("Enhanced Hip Firing...");
        int accuracy = hipFireAccuracy + enhancedAccuracyBonus;
        int damage = baseDamage + enhancedDamageBonus;

        if (new Random().nextInt(100) < accuracy) {
            comboCount++;
            System.out.println("Hit! Damage dealt: " + (damage + comboCount * comboBonus));
        } else {
            comboCount = 0;
            System.out.println("Missed!");
        }
    }

    public void aimAndShoot() {
        System.out.println("Aiming and Shooting...");
        if (new Random().nextInt(100) < aimAccuracy) {
            comboCount++;
            System.out.println("Hit! Damage dealt: " + (baseDamage + comboCount * comboBonus));
        } else {
            comboCount = 0;
            System.out.println("Missed!");
        }
    }

    public void useSpecialSkill() {
        if (currentCooldown > 0) {
            System.out.println("Special skill is on cooldown. Cooldown turns left: " + currentCooldown);
            return;
        }

        System.out.println("Using Special Skill...");
        if (new Random().nextInt(100) < aimAccuracy) {
            comboCount++;
            System.out.println("Hit! Damage dealt: " + (specialSkillDamage + comboCount * comboBonus));
        } else {
            comboCount = 0;
            System.out.println("Missed!");
        }

        currentCooldown = specialSkillCooldown;
    }

    public void checkEquipment() {
        System.out.println("Current Equipment: " + equipment);
        System.out.println("Do you want to upgrade your equipment? (yes/no)");
        Scanner scanner = new Scanner(System.in);
        String input = scanner.nextLine();

        if (input.equalsIgnoreCase("yes")) {
            upgradeEquipment();
        } else {
            System.out.println("Equipment check complete.");
        }
    }

    private void upgradeEquipment() {
        System.out.println("Upgrading equipment...");
        equipment = "Advanced Weapon";
        hipFireAccuracy += 10;
        aimAccuracy += 10;
        enhancedAccuracyBonus += 10;
        enhancedDamageBonus += 5;
        baseDamage += 5;
        specialSkillDamage += 10;
        System.out.println("Equipment upgraded to Advanced Weapon!");
    }

    // Update cooldown every turn
    public void updateCooldown() {
        if (currentCooldown > 0) {
            currentCooldown--;
        }
    }
}