import java.util.ArrayList;
import java.util.List;

public class SuperEnhancedGun {
    private String name;
    private double baseDamage;
    private double damageMultiplier;
    private double fireRate; // 射速（每秒发射次数）
    private double range; // 射程（单位：米）
    private double accuracy; // 精准度（0到1之间，1表示完美精准）
    private List<String> attachments; // 配件列表

    // 构造器
    public SuperEnhancedGun(String name, double baseDamage, double fireRate, double range, double accuracy) {
        this.name = name;
        this.baseDamage = baseDamage;
        this.damageMultiplier = 1.0;
        this.fireRate = fireRate;
        this.range = range;
        this.accuracy = accuracy;
        this.attachments = new ArrayList<>();
    }

    // 设置伤害增强倍数的方法
    public void enhanceDamage(double multiplier) {
        this.damageMultiplier += multiplier;
        System.out.println(name + "的伤害增强了，当前倍数为: " + this.damageMultiplier);
    }

    // 添加配件
    public void addAttachment(String attachment) {
        if (!attachments.contains(attachment)) {
            attachments.add(attachment);
            System.out.println("已为" + name + "添加配件: " + attachment);
            updateStatsBasedOnAttachments();
        } else {
            System.out.println("该配件已添加过: " + attachment);
        }
    }

    // 根据配件更新枪械属性
    private void updateStatsBasedOnAttachments() {
        for (String attachment : attachments) {
            switch (attachment) {
                case "瞄准镜":
                    accuracy += 0.1;
                    break;
                case "消音器":
                    fireRate += 0.2;
                    break;
                case "扩容弹夹":
                    fireRate += 0.1;
                    break;
                case "枪口补偿器":
                    accuracy += 0.1;
                    break;
                default:
                    System.out.println("未知配件: " + attachment);
            }
        }
    }

    // 计算实际伤害值的方法
    public double calculateDamage() {
        return baseDamage * damageMultiplier;
    }

    // 获取枪械名称
    public String getName() {
        return name;
    }

    // 获取枪械基础伤害
    public double getBaseDamage() {
        return baseDamage;
    }

    // 获取当前伤害增强倍数
    public double getDamageMultiplier() {
        return damageMultiplier;
    }

    // 获取射速
    public double getFireRate() {
        return fireRate;
    }

    // 获取射程
    public double getRange() {
        return range;
    }

    // 获取精准度
    public double getAccuracy() {
        return accuracy;
    }

    // 获取配件列表
    public List<String> getAttachments() {
        return attachments;
    }

    // 模拟射击
    public void simulateShooting() {
        System.out.println("模拟射击：");
        System.out.println("枪械名称: " + name);
        System.out.println("基础伤害: " + baseDamage);
        System.out.println("增强后伤害: " + calculateDamage());
        System.out.println("射速: " + fireRate + " 发/秒");
        System.out.println("射程: " + range + " 米");
        System.out.println("精准度: " + accuracy);
        System.out.println("配件: " + attachments);
    }
}

// 使用示例
public class Main {
    public static void main(String[] args) {
        SuperEnhancedGun assaultRifle = new SuperEnhancedGun("M4A1", 25.0, 10.0, 500.0, 0.8);

        System.out.println("原始伤害: " + assaultRifle.calculateDamage());

        assaultRifle.enhanceDamage(0.5); // 增强伤害50%
        assaultRifle.addAttachment("瞄准镜");
        assaultRifle.addAttachment("消音器");

        System.out.println("增强后伤害: " + assaultRifle.calculateDamage());

        assaultRifle.simulateShooting();
    }
}