import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;

public class GamePanel extends JPanel implements ActionListener {
    private Timer timer;
    private int playerX, playerY;
    private int playerSpeed = 5;
    private boolean hasGun = false;
    private int gunX, gunY;

    public GamePanel() {
        // 设置面板大小
        setPreferredSize(new Dimension(800, 600));
        setBackground(Color.BLACK);

        // 初始化玩家位置
        playerX = 400;
        playerY = 300;

        // 初始化枪械位置（据点位置）
        gunX = 100;
        gunY = 100;

        // 创建一个定时器，每16毫秒更新一次（大约60帧/秒）
        timer = new Timer(16, this);
        timer.start();

        // 添加键盘监听
        addKeyListener(new KeyAdapter() {
            @Override
            public void keyPressed(KeyEvent e) {
                switch (e.getKeyCode()) {
                    case KeyEvent.VK_UP:
                        playerY -= playerSpeed;
                        break;
                    case KeyEvent.VK_DOWN:
                        playerY += playerSpeed;
                        break;
                    case KeyEvent.VK_LEFT:
                        playerX -= playerSpeed;
                        break;
                    case KeyEvent.VK_RIGHT:
                        playerX += playerSpeed;
                        break;
                }
                checkGunPickup();
                repaint(); // 重新绘制面板
            }
        });
        setFocusable(true); // 确保面板可以获取焦点
    }

    private void checkGunPickup() {
        // 检查玩家是否进入据点范围
        if (playerX > gunX - 50 && playerX < gunX + 50 &&
            playerY > gunY - 50 && playerY < gunY + 50) {
            hasGun = true;
        }
    }

    @Override
    protected void paintComponent(Graphics g) {
        super.paintComponent(g);
        // 绘制玩家（一个蓝色矩形）
        g.setColor(Color.BLUE);
        g.fillRect(playerX, playerY, 50, 50);

        // 绘制据点（一个绿色矩形）
        g.setColor(Color.GREEN);
        g.fillRect(gunX, gunY, 50, 50);

        // 如果玩家有枪，绘制枪械（一个红色矩形）
        if (hasGun) {
            g.setColor(Color.RED);
            g.fillRect(playerX + 20, playerY - 20, 10, 30);
        }
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        // 定时器触发时更新游戏逻辑（这里可以添加更多逻辑）
        repaint(); // 重新绘制面板
    }

    public static void main(String[] args) {
        // 创建窗口
        JFrame frame = new JFrame("Java Game - Gun Pickup");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setResizable(false);
        frame.add(new GamePanel());
        frame.pack();
        frame.setLocationRelativeTo(null);
        frame.setVisible(true);
    }
}
