import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.util.ArrayList;
import java.util.List;

public class GamePanel extends JPanel implements ActionListener {
    private Timer timer;
    private int playerX, playerY;
    private int playerSpeed = 5;
    private int enemyX, enemyY;
    private List<Bullet> bullets;

    public GamePanel() {
        // 设置面板大小
        setPreferredSize(new Dimension(800, 600));
        setBackground(Color.BLACK);

        // 初始化玩家位置
        playerX = 400;
        playerY = 500;

        // 初始化敌人位置
        enemyX = 400;
        enemyY = 100;

        // 初始化子弹列表
        bullets = new ArrayList<>();

        // 创建一个定时器，每16毫秒更新一次（大约60帧/秒）
        timer = new Timer(16, this);
        timer.start();

        // 添加键盘监听
        addKeyListener(new KeyAdapter() {
            @Override
            public void keyPressed(KeyEvent e) {
                switch (e.getKeyCode()) {
                    case KeyEvent.VK_UP:
                        playerY -= playerSpeed;
                        break;
                    case KeyEvent.VK_DOWN:
                        playerY += playerSpeed;
                        break;
                    case KeyEvent.VK_LEFT:
                        playerX -= playerSpeed;
                        break;
                    case KeyEvent.VK_RIGHT:
                        playerX += playerSpeed;
                        break;
                    case KeyEvent.VK_SPACE:
                        // 发射子弹
                        bullets.add(new Bullet(playerX + 25, playerY));
                        break;
                }
                repaint(); // 重新绘制面板
            }
        });
        setFocusable(true); // 确保面板可以获取焦点
    }

    @Override
    protected void paintComponent(Graphics g) {
        super.paintComponent(g);
        // 绘制玩家（一个蓝色矩形）
        g.setColor(Color.BLUE);
        g.fillRect(playerX, playerY, 50, 50);

        // 绘制敌人（一个红色矩形）
        g.setColor(Color.RED);
        g.fillRect(enemyX, enemyY, 50, 50);

        // 绘制子弹
        for (Bullet bullet : bullets) {
            bullet.update();
            g.setColor(Color.YELLOW);
            g.fillRect(bullet.x, bullet.y, 10, 10);
        }
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        // 定时器触发时更新游戏逻辑
        // 检查子弹是否击中敌人
        for (Bullet bullet : new ArrayList<>(bullets)) {
            if (bullet.y <= enemyY + 50 && bullet.y >= enemyY &&
                bullet.x >= enemyX && bullet.x <= enemyX + 50) {
                // 子弹击中敌人
                bullets.remove(bullet);
                // 可以在这里添加击中敌人的效果
            }
        }
        repaint(); // 重新绘制面板
    }

    public static void main(String[] args) {
        // 创建窗口
        JFrame frame = new JFrame("Java Game - Lock-on Bullets");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setResizable(false);
        frame.add(new GamePanel());
        frame.pack();
        frame.setLocationRelativeTo(null);
        frame.setVisible(true);
    }

    // 子弹类
    class Bullet {
        int x, y;

        public Bullet(int x, int y) {
            this.x = x;
            this.y = y;
        }

        public void update() {
            // 子弹自动锁定并移动到敌人位置
            if (y > enemyY) {
                y -= 10; // 子弹速度
            }
        }
    }
}
