// 定义角色类
class Character {
    private String name; // 角色名称
    private int attack; // 攻击力
    private int defense; // 防御力
    private int damageReduction; // 减伤值
    private int health; // 生命值
    private static final int MAX_DAMAGE_REDUCTION = 100; // 减伤的最大值

    // 构造函数
    public Character(String name, int attack, int defense, int health) {
        this.name = name;
        this.attack = attack;
        this.defense = defense;
        this.health = health;
        this.damageReduction = 0; // 初始减伤值为0
    }

    // 获取和设置属性的方法
    public String getName() {
        return name;
    }

    public int getAttack() {
        return attack;
    }

    public void setAttack(int attack) {
        this.attack = attack;
    }

    public int getDefense() {
        return defense;
    }

    public void setDefense(int defense) {
        this.defense = defense;
    }

    public int getDamageReduction() {
        return damageReduction;
    }

    // 设置减伤值，并确保其在合理范围内
    public void setDamageReduction(int damageReduction) {
        if (damageReduction < 0) {
            this.damageReduction = 0; // 减伤值不能为负
        } else if (damageReduction > MAX_DAMAGE_REDUCTION) {
            this.damageReduction = MAX_DAMAGE_REDUCTION; // 减伤值不能超过上限
        } else {
            this.damageReduction = damageReduction;
        }
    }

    public int getHealth() {
        return health;
    }

    public void setHealth(int health) {
        this.health = health;
    }

    // 计算实际受到的伤害
    public int calculateDamageTaken(int incomingDamage) {
        int actualDamage = incomingDamage - defense - damageReduction;
        return Math.max(actualDamage, 0); // 伤害不能小于0
    }

    // 受到伤害时更新生命值
    public void takeDamage(int incomingDamage) {
        int actualDamage = calculateDamageTaken(incomingDamage);
        health -= actualDamage;
        System.out.println(name + " took " + actualDamage + " damage. Health remaining: " + health);
    }

    // 修复减伤值
    public void repairDamageReduction() {
        if (damageReduction < 0) {
            damageReduction = 0; // 如果减伤值为负，修复为0
        }
        System.out.println(name + "'s damage reduction has been repaired to " + damageReduction);
    }
}

// 测试类
public class CharacterSystem {
    public static void main(String[] args) {
        // 创建角色
        Character character = new Character("Warrior", 100, 50, 1000);

        // 输出初始属性
        System.out.println("Initial Attributes:");
        System.out.println("Name: " + character.getName());
        System.out.println("Attack: " + character.getAttack());
        System.out.println("Defense: " + character.getDefense());
        System.out.println("DamageReduction: " + character.getDamageReduction());
        System.out.println("Health: " + character.getHealth());

        // 设置减伤值
        character.setDamageReduction(30);
        System.out.println("Updated DamageReduction: " + character.getDamageReduction());

        // 角色受到伤害
        character.takeDamage(150);

        // 尝试设置一个不合理的减伤值
        character.setDamageReduction(-20); // 尝试设置负值
        System.out.println("After setting negative DamageReduction: " + character.getDamageReduction());

        // 修复减伤值
        character.repairDamageReduction();

        // 角色再次受到伤害
        character.takeDamage(150);
    }
}