import java.awt.*;
import java.awt.event.*;
import java.util.Random;

// 玩家类
class Player {
    private double x, y, z; // 玩家位置
    private double aimX, aimY; // 玩家准星朝向（水平和垂直角度）

    public Player(double x, double y, double z) {
        this.x = x;
        this.y = y;
        this.z = z;
        this.aimX = 0;
        this.aimY = 0;
    }

    public void setAim(double aimX, double aimY) {
        this.aimX = aimX;
        this.aimY = aimY;
    }

    public double getX() {
        return x;
    }

    public double getY() {
        return y;
    }

    public double getZ() {
        return z;
    }

    public double getAimX() {
        return aimX;
    }

    public double getAimY() {
        return aimY;
    }
}

// 目标类
class Target {
    private double x, y, z; // 目标位置

    public Target(double x, double y, double z) {
        this.x = x;
        this.y = y;
        this.z = z;
    }

    public double getX() {
        return x;
    }

    public double getY() {
        return y;
    }

    public double getZ() {
        return z;
    }
}

// 自动瞄准算法
class AutoAim {
    public static void aimAtHead(Player player, Target target) {
        // 计算水平角度
        double deltaX = target.getX() - player.getX();
        double deltaY = target.getY() - player.getY();
        double angleX = Math.atan2(deltaY, deltaX) - Math.PI / 2;

        // 计算垂直角度
        double horizontalDistance = Math.sqrt(deltaX * deltaX + deltaY * deltaY);
        double deltaZ = target.getZ() - player.getZ();
        double angleY;
        if (deltaZ > 0) {
            angleY = Math.atan2(deltaZ, horizontalDistance);
        } else {
            angleY = -Math.atan2(-deltaZ, horizontalDistance);
        }

        // 设置玩家准星朝向
        player.setAim(angleX, angleY);
    }
}

// 游戏面板
class GamePanel extends JPanel implements ActionListener, KeyListener {
    private Timer timer;
    private Player player;
    private Target target;

    public GamePanel() {
        timer = new Timer(30, this); // 定时器，每30ms更新一次
        player = new Player(100, 100, 0); // 玩家初始位置
        target = new Target(300, 300, 100); // 目标初始位置
        addKeyListener(this);
        setFocusable(true);
        timer.start();
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        // 自动瞄准目标头部
        AutoAim.aimAtHead(player, target);
        repaint();
    }

    @Override
    protected void paintComponent(Graphics g) {
        super.paintComponent(g);
        // 绘制玩家
        g.setColor(Color.BLUE);
        g.fillOval((int) player.getX(), (int) player.getY(), 20, 20);
        // 绘制目标
        g.setColor(Color.RED);
        g.fillOval((int) target.getX(), (int) target.getY(), 20, 20);
        // 绘制准星
        g.setColor(Color.GREEN);
        g.drawLine((int) player.getX(), (int) player.getY(),
                (int) (player.getX() + Math.cos(player.getAimX()) * 100),
                (int) (player.getY() + Math.sin(player.getAimX()) * 100));
    }

    @Override
    public void keyPressed(KeyEvent e) {
        // 按下空格键时自动瞄准目标头部
        if (e.getKeyCode() == KeyEvent.VK_SPACE) {
            AutoAim.aimAtHead(player, target);
        }
    }

    @Override
    public void keyReleased(KeyEvent e) {
    }

    @Override
    public void keyTyped(KeyEvent e) {
    }
}

// 主程序
public class M416AutoAim {
    public static void main(String[] args) {
        JFrame frame = new JFrame("M416强锁自瞄");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setSize(600, 600);
        frame.add(new GamePanel());
        frame.setVisible(true);
    }
}
