import javafx.animation.AnimationTimer;
import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.canvas.Canvas;
import javafx.scene.canvas.GraphicsContext;
import javafx.scene.layout.Pane;
import javafx.scene.paint.Color;
import javafx.stage.Stage;

import java.util.ArrayList;
import java.util.List;

// 主应用程序类
public class BulletTrackingApp extends Application {

    private static final int WIDTH = 800;
    private static final int HEIGHT = 600;
    private static final double BULLET_SPEED = 5.0;
    private static final double ANGLE_DEGREES = -45.0; // 发射角度

    @Override
    public void start(Stage primaryStage) {
        primaryStage.setTitle("子弹追踪模拟器");

        Pane root = new Pane();
        Canvas canvas = new Canvas(WIDTH, HEIGHT);
        GraphicsContext gc = canvas.getGraphicsContext2D();
        root.getChildren().add(canvas);

        Scene scene = new Scene(root);
        primaryStage.setScene(scene);
        primaryStage.show();

        // 创建一个子弹实例
        Bullet bullet = new Bullet(WIDTH / 2, HEIGHT, Math.toRadians(ANGLE_DEGREES), BULLET_SPEED);

        // 动画计时器，用于更新和绘制子弹
        new AnimationTimer() {
            @Override
            public void handle(long now) {
                // 清除画布
                gc.setFill(Color.WHITE);
                gc.fillRect(0, 0, WIDTH, HEIGHT);

                // 更新子弹
                bullet.update();

                // 绘制子弹轨迹
                gc.setStroke(Color.RED);
                List<Point> history = bullet.getHistory();
                for (int i = 1; i < history.size(); i++) {
                    Point p1 = history.get(i - 1);
                    Point p2 = history.get(i);
                    gc.strokeLine(p1.x, p1.y, p2.x, p2.y);
                }

                // 绘制子弹当前位置
                gc.setFill(Color.BLACK);
                Point current = history.get(history.size() - 1);
                gc.fillOval(current.x - 5, current.y - 5, 10, 10);

                // 如果子弹超出边界，重置子弹
                if (current.x < 0 || current.x > WIDTH || current.y < 0 || current.y > HEIGHT) {
                    bullet.reset(WIDTH / 2, HEIGHT, Math.toRadians(ANGLE_DEGREES), BULLET_SPEED);
                }
            }
        }.start();
    }

    // 子弹类
    class Bullet {
        double x;
        double y;
        double angle;
        double speed;
        List<Point> history;

        public Bullet(double startX, double startY, double angle, double speed) {
            this.x = startX;
            this.y = startY;
            this.angle = angle;
            this.speed = speed;
            this.history = new ArrayList<>();
            this.history.add(new Point(x, y));
        }

        public void update() {
            x += speed * Math.cos(angle);
            y += speed * Math.sin(angle);
            history.add(new Point(x, y));
        }

        public List<Point> getHistory() {
            return history;
        }

        public void reset(double startX, double startY, double angle, double speed) {
            this.x = startX;
            this.y = startY;
            this.angle = angle;
            this.speed = speed;
            this.history.clear();
            this.history.add(new Point(x, y));
        }
    }

    // 点类
    class Point {
        double x;
        double y;

        public Point(double x, double y) {
            this.x = x;
            this.y = y;
        }
    }

    // 主方法
    public static void main(String[] args) {
        launch(args);
    }
}