-- 增强版整合所有功能的模块
Integrator = {}

-- 配置表，用于参数化各项功能
Integrator.config = {
    no_recoil = {
        bullet_speed = 1500,          -- 子弹速度
        gun_shake = 0.3,              -- 枪械震动幅度
        follow_distance = 15,         -- 跟随敌人的距离阈值
    },
    bullet_damage = {
        max_bullet_speed = 1200,      -- 子弹最大速度
        max_distance = 1200,          -- 子弹最远距离
        damage_multiplier = 12,       -- 伤害倍数
    },
    gun_aid_scope = {
        aid_scope_range = 360,        -- 辅助瞄准范围（度）
        trigger_delay = 0.1,          -- 触发延迟（秒）
    },
    matching_mechanism = {
        strong_match_level = 1500,    -- 匹配强劲度
        match_interval = 2,           -- 匹配间隔（秒）
    },
    self_movement = {
        move_speed_multiplier = 6,    -- 自身移动速度倍数
        acceleration_factor = 1.5,     -- 行为加速因子
    },
    damage_reduction = {
        damage_reduction_percentage = 85, -- 伤害降低百分比
    },
    enemy_damage = {
        damage_multiplier = 12,       -- 对敌人造成的伤害倍数
    },
}

-- 子弹速度和无后座功能
function Integrator.no_recoil(config)
    -- 设置子弹速度
    set_bullet_speed(config.bullet_speed)
    
    -- 设置枪械震动
    set_gun_shake(config.gun_shake)
    
    -- 跟随敌人函数
    local function follow_enemy()
        local target_pos = get_target_position()
        local player_pos = get_player_position()
        local distance = math.sqrt((target_pos.x - player_pos.x)^2 + (target_pos.y - player_pos.y)^2)
        
        if distance < config.follow_distance then
            set_player_position(target_pos.x, target_pos.y)
            start_gun_shake(config.gun_shake)
        end
    end
    
    -- 定时调用跟随敌人函数
    set_interval(function() follow_enemy() end, 0.05)  -- 每50毫秒调用一次
end

-- 子弹伤害和距离限制功能
function Integrator.bullet_damage(config)
    set_bullet_speed(config.max_bullet_speed)
    set_max_distance(config.max_distance)
    set_damage_multiplier(config.damage_multiplier)
end

-- 枪械辅助瞄准360°响应触发功能
function Integrator.gun_aid_scope(config)
    set_aid_scope_range(config.aid_scope_range)
    
    -- 定时触发辅助瞄准
    set_interval(function() trigger_gun_aid_scope() end, config.trigger_delay)
end

-- 匹配机制功能
function Integrator.matching_mechanism(config)
    set_strong_match_level(config.strong_match_level)
    
    -- 定时进行匹配
    set_interval(function() start_matching() end, config.match_interval)
end

-- 自身移动速度和玩家行为加速功能
function Integrator.self_movement(config)
    set_move_speed_multiplier(config.move_speed_multiplier)
    increase_self_move_speed()
    
    -- 加速玩家行为
    accelerate_player_behavior(config.acceleration_factor)
end

-- 敌人子弹攻击降低自身伤害功能
function Integrator.damage_reduction(config)
    set_damage_reduction_percentage(config.damage_reduction_percentage)
    reduce_enemy_bullet_attack_damage_on_self()
end

-- 对敌人造成伤害增加功能
function Integrator.enemy_damage(config)
    set_damage_multiplier(config.damage_multiplier)
    increase_my_character_bullet_damage_on_enemy()
end

-- 整合所有功能
function Integrator.integrate_all()
    -- 调用各个功能模块，并传入配置参数
    Integrator.no_recoil(Integrator.config.no_recoil)
    Integrator.bullet_damage(Integrator.config.bullet_damage)
    Integrator.gun_aid_scope(Integrator.config.gun_aid_scope)
    Integrator.matching_mechanism(Integrator.config.matching_mechanism)
    Integrator.self_movement(Integrator.config.self_movement)
    Integrator.damage_reduction(Integrator.config.damage_reduction)
    Integrator.enemy_damage(Integrator.config.enemy_damage)
end

-- 初始化并启动整合
Integrator.integrate_all()

-- 以下是假设存在的底层函数实现（需要根据实际情况实现）
-- 示例：
-- function set_bullet_speed(speed)
--     -- 设置子弹速度的底层实现
-- end
-- 
-- function get_target_position()
--     -- 获取目标位置的底层实现
--     return {x = 0, y = 0}
-- end
-- 
-- function get_player_position()
--     -- 获取玩家位置的底层实现
--     return {x = 0, y = 0}
-- end
-- 
-- function set_player_position(x, y)
--     -- 设置玩家位置的底层实现
-- end
-- 
-- function start_gun_shake(shake_amount)
--     -- 开始枪械震动的底层实现
-- end
-- 
-- function set_max_distance(distance)
--     -- 设置子弹最远距离的底层实现
-- end
-- 
-- function set_damage_multiplier(multiplier)
--     -- 设置伤害倍数的底层实现
-- end
-- 
-- function set_aid_scope_range(range)
--     -- 设置辅助瞄准范围的底层实现
-- end
-- 
-- function trigger_gun_aid_scope()
--     -- 触发辅助瞄准的底层实现
-- end
-- 
-- function set_strong_match_level(level)
--     -- 设置匹配强劲度的底层实现
-- end
-- 
-- function start_matching()
--     -- 开始匹配的底层实现
-- end
-- 
-- function set_move_speed_multiplier(multiplier)
--     -- 设置自身移动速度倍数的底层实现
-- end
-- 
-- function increase_self_move_speed()
--     -- 增加自身移动速度的底层实现
-- end
-- 
-- function accelerate_player_behavior(factor)
--     -- 加速玩家行为的底层实现
-- end
-- 
-- function set_damage_reduction_percentage(percentage)
--     -- 设置伤害降低百分比的底层实现
-- end
-- 
-- function reduce_enemy_bullet_attack_damage_on_self()
--     -- 减少敌人子弹攻击自身伤害的底层实现
-- end
-- 
-- function set_damage_multiplier(multiplier)
--     -- 设置对敌人造成伤害倍数的底层实现
-- end
-- 
-- function increase_my_character_bullet_damage_on_enemy()
--     -- 增加对敌人造成伤害的底层实现
-- end