import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

class Shot {
    double x;
    double y;
    double targetX;
    double targetY;
    boolean headshot;

    public Shot(double x, double y, double targetX, double targetY, boolean headshot) {
        this.x = x;
        this.y = y;
        this.targetX = targetX;
        this.targetY = targetY;
        this.headshot = headshot;
    }
}

public class HeadshotAnalyzer {
    public static void main(String[] args) {
        String filePath = "shooting_log.txt"; // 替换为你的日志文件路径
        List<Shot> shots = new ArrayList<>();

        // 读取日志文件并解析数据
        try (BufferedReader br = new BufferedReader(new FileReader(filePath))) {
            String line;
            while ((line = br.readLine()) != null) {
                String[] parts = line.split(",");
                double x = Double.parseDouble(parts[0]);
                double y = Double.parseDouble(parts[1]);
                double targetX = Double.parseDouble(parts[2]);
                double targetY = Double.parseDouble(parts[3]);
                boolean headshot = Boolean.parseBoolean(parts[4]);
                shots.add(new Shot(x, y, targetX, targetY, headshot));
            }
        } catch (IOException e) {
            e.printStackTrace();
        }

        // 计算爆头率
        int headshotCount = 0;
        for (Shot shot : shots) {
            if (shot.headshot) {
                headshotCount++;
            }
        }
        double headshotRate = (double) headshotCount / shots.size() * 100;
        System.out.printf("爆头率: %.2f%%\n", headshotRate);

        // 分析爆头率并提供建议
        if (headshotRate < 50.0) {
            System.out.println("建议：提高瞄准精度，练习爆头线技巧。");
        } else if (headshotRate < 75.0) {
            System.out.println("建议：继续练习，保持当前水平并尝试提高。");
        } else {
            System.out.println("恭喜！你的爆头率非常高，继续保持！");
        }

        // 进一步分析：平均射击距离与爆头率的关系
        double totalDistance = 0.0;
        for (Shot shot : shots) {
            double distance = Math.sqrt(Math.pow(shot.x - shot.targetX, 2) + Math.pow(shot.y - shot.targetY, 2));
            totalDistance += distance;
        }
        double averageDistance = totalDistance / shots.size();
        System.out.printf("平均射击距离: %.2f 米\n", averageDistance);

        // 根据平均射击距离提供建议
        if (averageDistance < 50.0) {
            System.out.println("建议：多练习中近距离战斗，提高反应速度。");
        } else {
            System.out.println("建议：多练习远距离射击，提高预判能力。");
        }
    }
}