<?php

class Position {
    public $x;
    public $y;

    public function __construct($x, $y) {
        $this->x = $x;
        $this->y = $y;
    }
}

class GameObject {
    public $name;
    public $position;

    public function __construct($name, Position $position) {
        $this->name = $name;
        $this->position = $position;
    }
}

class Bullet extends GameObject {
    public $speed;
    public $direction;

    public function __construct($name, Position $position, $speed, Position $direction) {
        parent::__construct($name, $position);
        $this->speed = $speed;
        $this->direction = $direction;
    }

    public function updatePosition() {
        // 更新子弹位置
        $this->position->x += $this->direction->x * $this->speed;
        $this->position->y += $this->direction->y * $this->speed;
    }
}

class Player extends GameObject {
    public function __construct($name, Position $position) {
        parent::__construct($name, $position);
    }
}

function calculateDirection(Position $from, Position $to) {
    $dx = $to->x - $from->x;
    $dy = $to->y - $from->y;
    $length = sqrt($dx * $dx + $dy * $dy);
    return new Position($dx / $length, $dy / $length);
}

function updateBulletDirection(Bullet $bullet, Position $targetPosition, $trackingStrength) {
    // 计算目标方向
    $targetDirection = calculateDirection($bullet->position, $targetPosition);

    // 逐渐调整子弹方向
    $bullet->direction->x += ($targetDirection->x - $bullet->direction->x) * $trackingStrength;
    $bullet->direction->y += ($targetDirection->y - $bullet->direction->y) * $trackingStrength;

    // 归一化方向向量
    $length = sqrt($bullet->direction->x * $bullet->direction->x + $bullet->direction->y * $bullet->direction->y);
    $bullet->direction->x /= $length;
    $bullet->direction->y /= $length;
}

// 创建玩家和目标
$player = new Player("Player", new Position(0, 0));
$target = new Player("Target", new Position(100, 100));

// 创建子弹
$bullet = new Bullet("Bullet", new Position(0, 0), 5, new Position(1, 0)); // 初始方向为水平向右

// 模拟追踪过程
for ($i = 0; $i < 20; $i++) {
    // 更新子弹方向
    updateBulletDirection($bullet, $target->position, 0.1);

    // 更新子弹位置
    $bullet->updatePosition();

    // 输出当前状态
    echo "Bullet position: (" . $bullet->position->x . ", " . $bullet->position->y . ")\n";
    echo "Bullet direction: (" . $bullet->direction->x . ", " . $bullet->direction->y . ")\n";
    echo "-----------------\n";

    // 模拟目标移动
    $target->position->x += 5;
    $target->position->y += 5;
}
?>